@@ -52,6 +52,12 @@ pub struct TextInput<'video> {
     video: PhantomData<&'video Video<'video>>,
 }
 
+impl std::fmt::Debug for TextInput<'_> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("TextInput").finish()
+    }
+}
+
 assert_not_impl_all!(TextInput: Send, Sync);
 
 impl<'video> TextInput<'video> {
