@@ -1,14 +1,20 @@
 #![allow(unused)]
 
+pub mod audio;
 mod bind;
 mod error;
 mod event;
+pub mod file;
+pub mod haptic;
+pub mod hint;
+pub mod power;
 mod sdl;
+pub mod system;
 mod timer;
 mod video;
 
 pub use error::*;
 pub use event::{app, EventBox};
 pub use sdl::Sdl;
-pub use timer::Timer;
+pub use timer::*;
 pub use video::*;
