@@ -13,11 +13,16 @@ pub struct Timer<'callback> {
     raw_callback: *mut TimerCallback<'callback>,
 }
 
+impl std::fmt::Debug for Timer<'_> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("Timer").field("id", &self.id).finish()
+    }
+}
+
 impl<'callback> Timer<'callback> {
     pub fn new(interval: u32, callback: TimerCallback<'callback>) -> Result<Self> {
         let wrapped = Box::into_raw(Box::new(callback));
-        let id =
-            unsafe { bind::SDL_AddTimer(interval, Some(timer_wrap_handler), wrapped as *mut _) };
+        let id = unsafe { bind::SDL_AddTimer(interval, Some(timer_wrap_handler), wrapped.cast()) };
         if id == 0 {
             Err(SdlError::Others { msg: Sdl::error() })
         } else {
