@@ -2,6 +2,7 @@ use std::ffi::CString;
 
 use crate::bind;
 
+#[derive(Debug, PartialEq, Eq)]
 pub struct ClipboardText {
     text: String,
 }
@@ -13,11 +14,15 @@ impl ClipboardText {
             return None;
         }
         let text = unsafe { CString::from_raw(ptr) }.into_string().ok()?;
-        unsafe { bind::SDL_free(ptr as *mut _) }
+        unsafe { bind::SDL_free(ptr.cast()) }
         Some(Self { text })
     }
 
     pub fn text(&self) -> &String {
         &self.text
     }
+
+    pub fn into_string(self) -> String {
+        self.text
+    }
 }
