@@ -52,6 +52,12 @@ pub struct Window<'video> {
     video: &'video Video<'video>,
 }
 
+impl std::fmt::Debug for Window<'_> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("Window").field("id", &self.id()).finish()
+    }
+}
+
 assert_not_impl_all!(Window: Send, Sync);
 
 impl<'video> Window<'video> {
@@ -140,8 +146,6 @@ impl<'video> Window<'video> {
     pub fn surface(&self) -> WindowSurface {
         WindowSurface::new(self)
     }
-
-    // TODO(MikuroXina): open gl context
 }
 
 impl<'video> Drop for Window<'video> {
