@@ -8,6 +8,7 @@ use crate::{bind, Sdl, SdlError};
 
 use super::Window;
 
+#[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub enum SystemCursorKind {
     Arrow,
     IBeam,
@@ -48,6 +49,12 @@ pub struct Cursor<'window> {
     window: PhantomData<&'window ()>,
 }
 
+impl std::fmt::Debug for Cursor<'_> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("Cursor").finish()
+    }
+}
+
 assert_not_impl_all!(Cursor: Send, Sync);
 
 impl<'window> Cursor<'window> {
